==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/VerticalStackedSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedSeriesBaseDescriptionMetadata } from "./StackedSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
export let VerticalStackedSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class VerticalStackedSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (VerticalStackedSeriesBaseDescriptionMetadata.a == null) {
                VerticalStackedSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                VerticalStackedSeriesBaseDescriptionMetadata.c(VerticalStackedSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(VerticalStackedSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(VerticalStackedSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            StackedSeriesBaseDescriptionMetadata.c(a);
            a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
            a.item("XAxisRef@nameBinding", "true");
            a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
            a.item("YAxisRef@nameBinding", "true");
        }
        static d(a) {
            VerticalStackedSeriesBaseDescriptionMetadata.b(a);
            a.ac("VerticalStackedSeriesBase", VerticalStackedSeriesBaseDescriptionMetadata.a);
        }
    }
    VerticalStackedSeriesBaseDescriptionMetadata.$t = markType(VerticalStackedSeriesBaseDescriptionMetadata, 'VerticalStackedSeriesBaseDescriptionMetadata');
    VerticalStackedSeriesBaseDescriptionMetadata.a = null;
    return VerticalStackedSeriesBaseDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/VerticalStackedSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedSeriesBaseDescriptionMetadata } from "./StackedSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
export let VerticalStackedSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class VerticalStackedSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (VerticalStackedSeriesBaseDescriptionMetadata.a == null) {
                VerticalStackedSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                VerticalStackedSeriesBaseDescriptionMetadata.c(VerticalStackedSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(VerticalStackedSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(VerticalStackedSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            StackedSeriesBaseDescriptionMetadata.c(a);
            a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
            a.item("XAxisRef@nameBinding", "true");
            a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
            a.item("YAxisRef@nameBinding", "true");
        }
        static d(a) {
            VerticalStackedSeriesBaseDescriptionMetadata.b(a);
            a.ad("VerticalStackedSeriesBase", VerticalStackedSeriesBaseDescriptionMetadata.a);
        }
    }
    VerticalStackedSeriesBaseDescriptionMetadata.$t = markType(VerticalStackedSeriesBaseDescriptionMetadata, 'VerticalStackedSeriesBaseDescriptionMetadata');
    VerticalStackedSeriesBaseDescriptionMetadata.a = null;
    return VerticalStackedSeriesBaseDescriptionMetadata;
})();
